summaryrefslogtreecommitdiffstats
path: root/ksquirrel/sq_imageloader.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-03 01:36:58 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-03 01:36:58 +0000
commitd9d0ac84a2b1609ff81b399b81842a15704cbefd (patch)
tree58c783db373c4633201e5a9716901599c1afad92 /ksquirrel/sq_imageloader.h
parent63f270d62c4541f1379f0f82f5255a34e5037e00 (diff)
downloadksquirrel-d9d0ac84a2b1609ff81b399b81842a15704cbefd.tar.gz
ksquirrel-d9d0ac84a2b1609ff81b399b81842a15704cbefd.zip
TQt4 port ksquirrel
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ksquirrel@1239132 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksquirrel/sq_imageloader.h')
-rw-r--r--ksquirrel/sq_imageloader.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/ksquirrel/sq_imageloader.h b/ksquirrel/sq_imageloader.h
index 135c4a0..ecc8c77 100644
--- a/ksquirrel/sq_imageloader.h
+++ b/ksquirrel/sq_imageloader.h
@@ -18,9 +18,9 @@
#ifndef SQ_IMAGELOADER_H
#define SQ_IMAGELOADER_H
-#include <qstring.h>
-#include <qimage.h>
-#include <qobject.h>
+#include <tqstring.h>
+#include <tqimage.h>
+#include <tqobject.h>
#include "sq_codecsettings.h"
@@ -35,10 +35,10 @@ struct SQ_LIBRARY;
* (for generating thumbnails).
*/
-class SQ_ImageLoader : public QObject
+class SQ_ImageLoader : public TQObject
{
public:
- SQ_ImageLoader(QObject *parent);
+ SQ_ImageLoader(TQObject *tqparent);
~SQ_ImageLoader();
/*
@@ -47,12 +47,12 @@ class SQ_ImageLoader : public QObject
*
* If 'multi' is true, read all image pages from file.
*/
- bool loadImage(const QString &path, const SQ_CodecSettings::settings &sett, bool multi = false, int nomorethan = -1);
+ bool loadImage(const TQString &path, const SQ_CodecSettings::settings &sett, bool multi = false, int nomorethan = -1);
/*
* Try to determine image dimensions.
*/
- bool tasteImage(const QString &path, int *w, int *h, SQ_LIBRARY *_lib = 0);
+ bool tasteImage(const TQString &path, int *w, int *h, SQ_LIBRARY *_lib = 0);
/*
* Remove any previously saved data.
@@ -65,9 +65,9 @@ class SQ_ImageLoader : public QObject
RGBA* bits() const;
/*
* Return decoded image as QImage.
*/
- QImage image() const;
+ TQImage image() const;
/*
* Get a pointer to structure with information
@@ -65,9 +65,9 @@ class SQ_ImageLoader : public QObject
RGBA* bits() const;
/*
- * Return decoded image as QImage.
+ * Return decoded image as TQImage.
*/